function gameWorldInit()
	--setup world
	love.physics.setMeter(64)
	world = love.physics.newWorld(0, 9.81*64, true) 
	--setup objects table
	objects = {}
	--create test boundaries and ground
	createBoundariesAndGround()
	--create some blocks to test with
	objects.block1 = {}
	objects.block1.body = love.physics.newBody(world, 200, 550, "dynamic")
	objects.block1.shape = love.physics.newRectangleShape(0, 0, 50, 100)
	objects.block1.fixture = love.physics.newFixture(objects.block1.body, objects.block1.shape, 5)
	objects.block2 = {}
	objects.block2.body = love.physics.newBody(world, 200, 400, "dynamic")
	objects.block2.shape = love.physics.newRectangleShape(0, 0, 100, 50)
	objects.block2.fixture = love.physics.newFixture(objects.block2.body, objects.block2.shape, 2)
	--initalize and spawn player
	playerInit(325, 325)
	--spawn some enemies
	enemySpawn(300,300,300,300)
	enemySpawn(800,300)
	enemySpawn(800,600)
end
 
function gameWorldUpdate(dt)
	--update physics world
	world:update(dt)
	--update player (including movement, "jumping", and variables)
	playerUpdate(dt)
	--update bullets
	bulletUpdate(dt)
	--update enemies
	enemyUpdate(dt)
	
	function love.keypressed(key)
		--determine bullet shooting direction, and also check to see if a bullet is being shot
		bulletShoot(key)
		--quit game
		quitGame(key)
	end
end
 
function gameWorldDraw()
	--draw boundaries and ground
	drawBoundariesAndGround()
	--draw player
	playerDraw(dt)
	--draw bullets
	bulletDraw()
	--draw enemies
	enemyDraw()
	--draw testing blocks
	love.graphics.setColor(50, 50, 50)
	love.graphics.polygon("fill", objects.block1.body:getWorldPoints(objects.block1.shape:getPoints()))
	love.graphics.polygon("fill", objects.block2.body:getWorldPoints(objects.block2.shape:getPoints()))
end

function createBoundariesAndGround()
	--create ground
	objects.ground = {}
	objects.ground.body = love.physics.newBody(world, 1280/2, 1024-50/2) 
	objects.ground.shape = love.physics.newRectangleShape(1280, 50)
	objects.ground.fixture = love.physics.newFixture(objects.ground.body, objects.ground.shape)
	--create invisible walls
	objects.leftWall = {}
	objects.leftWall.body = love.physics.newBody(world, -1, 1024/2) 
	objects.leftWall.shape = love.physics.newRectangleShape(3, 1024) 
	objects.leftWall.fixture = love.physics.newFixture(objects.leftWall.body, objects.leftWall.shape); 
	objects.rightWall = {}
	objects.rightWall.body = love.physics.newBody(world, 1281, 1024/2) 
	objects.rightWall.shape = love.physics.newRectangleShape(3, 1024) 
	objects.rightWall.fixture = love.physics.newFixture(objects.rightWall.body, objects.rightWall.shape)
	objects.topWall = {}
	objects.topWall.body = love.physics.newBody(world, 1280/2, -1) 
	objects.topWall.shape = love.physics.newRectangleShape(1280, 3)
	objects.topWall.fixture = love.physics.newFixture(objects.topWall.body, objects.topWall.shape)
end

function drawBoundariesAndGround()
	--draw ground
	love.graphics.setColor(72, 160, 14)
	love.graphics.polygon("fill", objects.ground.body:getWorldPoints(objects.ground.shape:getPoints()))
end